impala_unnest() unnests a
column of type ARRAY, MAP, or STRUCT
in a tbl_impala. These column types are referred to
as complex or nested types.
impala_unnest(data, col, ...)an object with class tbl_impala with the
complex column unnested into two or more separate columns
an object with class tbl_impala
the unquoted name of an ARRAY,
MAP, or STRUCT column
ignored (included for compatibility)
impala_unnest() currently can unnest only
one column, can only be applied once to a tbl_impala,
and must be applied to a tbl_impala representing an
Impala table or view before applying any other operations.